@@ -22,9 +22,13 @@ public:
     [[nodiscard]] QString engineName() const;
     void setEngineName(const QString &newEngineName);
 
+    [[nodiscard]] QString instanceName() const;
+    void setInstanceName(const QString &newInstanceName);
+
 private:
     QString mModelName;
     QString mEngineName;
+    QString mInstanceName;
 };
 
 }
