@@ -108,7 +108,7 @@ void TextAutoGenerateTextPlugin::initializeProgress(const SendToAssistantInfo &i
 {
     // Start progress
     d->manager->changeInProgress(info.chatId, info.messageUuid, true);
-    sendToAssistant(std::move(info));
+    sendToAssistant(info);
 }
 
 void TextAutoGenerateTextPlugin::sendMessage(const QByteArray &chatId, const QString &str)
@@ -216,4 +216,14 @@ QString TextAutoGenerateTextPlugin::convertEngineType(TextAutoGenerateText::Text
     return {};
 }
 
+QString TextAutoGenerateTextPlugin::fallBackModel() const
+{
+    // Fallback to first model
+    if (!mModels.isEmpty()) {
+        return mModels.constFirst().identifier;
+    }
+    qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Current model is empty. It will failed to work.";
+    return {};
+}
+
 #include "moc_textautogeneratetextplugin.cpp"
