@@ -11,6 +11,12 @@ class OllamaComboBoxWidget;
 class QPlainTextEdit;
 class KMessageWidget;
 class OllamaManager;
+class QDoubleSpinBox;
+class QSpinBox;
+namespace TextAutoGenerateText
+{
+class TextAutoGenerateNotWorkingMessageWidget;
+}
 class TEXTAUTOGENERATEOLLAMA_EXPORT OllamaConfigureWidget : public QWidget
 {
     Q_OBJECT
@@ -21,11 +27,18 @@ public:
     void loadSettings();
     void saveSettings();
 
+Q_SIGNALS:
+    void ollamaProcessOk(bool status);
+
 private:
     void fillModels();
+    void slotStartOllama();
+    QLineEdit *const mName;
     QLineEdit *const mServerUrl;
     QPlainTextEdit *const mPrompt;
     OllamaComboBoxWidget *const mModelComboBoxWidget;
-    KMessageWidget *const mMessageWidget;
+    TextAutoGenerateText::TextAutoGenerateNotWorkingMessageWidget *const mMessageWidget;
+    QDoubleSpinBox *const mTemperature;
+    QSpinBox *const mSeed;
     OllamaManager *const mManager;
 };
