@@ -32,9 +32,11 @@ OllamaPlugin::OllamaPlugin(TextAutoGenerateText::TextAutoGenerateManager *manage
             setReady(true);
         }
     });
-    if (this->manager()->textAutoGenerateTextInstancesManager()->isCurrentInstance(instanceUuid())) {
-        mManager->loadModels();
-    }
+    connect(manager, &TextAutoGenerateText::TextAutoGenerateManager::loadEngineDone, this, [this]() {
+        if (this->manager()->textAutoGenerateTextInstancesManager()->isCurrentInstance(instanceUuid())) {
+            mManager->loadModels();
+        }
+    });
 }
 
 OllamaPlugin::~OllamaPlugin()
@@ -126,7 +128,6 @@ void OllamaPlugin::askToAssistant(const QString &msg)
 void OllamaPlugin::sendToAssistant(const SendToAssistantInfo &info)
 {
     TextAutoGenerateText::TextAutoGenerateTextRequest req;
-    req.setMessage(info.message);
     req.setModel(currentModel());
     req.setMessages(info.messagesArray);
     auto reply = mManager->getChatCompletion(req);
@@ -165,6 +166,9 @@ void OllamaPlugin::setDisplayName(const QString &newName)
 
 QString OllamaPlugin::currentModel() const
 {
+    if (mOllamaSettings->currentModel().isEmpty()) {
+        return fallBackModel();
+    }
     return mOllamaSettings->currentModel();
 }
 
