@@ -5,6 +5,7 @@
 */
 
 #include "richtextbrowser.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "widgets/textmessageindicator.h"
 #include <KCursor>
@@ -170,7 +171,7 @@ QMenu *RichTextBrowser::mousePopupMenu(QPoint pos)
 #if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
         if (!emptyDocument) {
             QAction *speakAction = popup->addAction(i18n("Speak Text"));
-            speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
+            speakAction->setIcon(QIcon::fromTheme(u"preferences-desktop-text-to-speech"_s));
             connect(speakAction, &QAction::triggered, this, &RichTextBrowser::slotSpeakText);
         }
 #endif
