@@ -5,6 +5,8 @@
 */
 
 #include "textgotolinewidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "widgets/textgotolinewidget.h"
 #include <QPushButton>
 #include <QSignalSpy>
@@ -27,12 +29,12 @@ void TextGoToLineWidgetTest::shouldHaveDefaultValuesOnCreation()
     TextCustomEditor::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    auto line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto line = edit.findChild<QSpinBox *>(u"line"_s);
     QVERIFY(line);
     QCOMPARE(line->minimum(), 1);
-    auto gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
+    auto gotolinebutton = edit.findChild<QPushButton *>(u"gotoline"_s);
     QVERIFY(gotolinebutton);
-    auto closebutton = edit.findChild<QToolButton *>(QStringLiteral("closebutton"));
+    auto closebutton = edit.findChild<QToolButton *>(u"closebutton"_s);
     QVERIFY(closebutton);
     QVERIFY(line->hasFocus());
 }
@@ -40,7 +42,7 @@ void TextGoToLineWidgetTest::shouldHaveDefaultValuesOnCreation()
 void TextGoToLineWidgetTest::shouldEmitGoToLineSignalWhenPressOnButton()
 {
     TextCustomEditor::TextGoToLineWidget edit;
-    auto gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
+    auto gotolinebutton = edit.findChild<QPushButton *>(u"gotoline"_s);
     QSignalSpy spy(&edit, &TextCustomEditor::TextGoToLineWidget::moveToLine);
     QTest::mouseClick(gotolinebutton, Qt::LeftButton);
     QCOMPARE(spy.count(), 1);
@@ -49,8 +51,8 @@ void TextGoToLineWidgetTest::shouldEmitGoToLineSignalWhenPressOnButton()
 void TextGoToLineWidgetTest::shouldEmitGoToLineSignalCorrectValueWhenPressOnButton()
 {
     TextCustomEditor::TextGoToLineWidget edit;
-    auto gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
-    auto line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto gotolinebutton = edit.findChild<QPushButton *>(u"gotoline"_s);
+    auto line = edit.findChild<QSpinBox *>(u"line"_s);
     line->setValue(5);
     QCOMPARE(line->value(), 5);
     QSignalSpy spy(&edit, &TextCustomEditor::TextGoToLineWidget::moveToLine);
@@ -65,7 +67,7 @@ void TextGoToLineWidgetTest::shouldHideWidgetWhenClickOnCloseButton()
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
     QVERIFY(edit.isVisible());
-    auto closebutton = edit.findChild<QToolButton *>(QStringLiteral("closebutton"));
+    auto closebutton = edit.findChild<QToolButton *>(u"closebutton"_s);
     QTest::mouseClick(closebutton, Qt::LeftButton);
     QVERIFY(!edit.isVisible());
 }
@@ -84,7 +86,7 @@ void TextGoToLineWidgetTest::shouldEmitGoToLineSignalWhenSpinboxHasFocusAndWePre
     TextCustomEditor::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    auto line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto line = edit.findChild<QSpinBox *>(u"line"_s);
     line->setFocus();
     QVERIFY(line->hasFocus());
     line->setValue(5);
@@ -99,7 +101,7 @@ void TextGoToLineWidgetTest::shouldHasFocusEachTimeThatItShown()
     TextCustomEditor::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    auto line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto line = edit.findChild<QSpinBox *>(u"line"_s);
     QVERIFY(line);
     QVERIFY(line->hasFocus());
     edit.hide();
@@ -114,7 +116,7 @@ void TextGoToLineWidgetTest::shouldSetFocusWhenWeRecallGotToLine()
     TextCustomEditor::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    auto line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto line = edit.findChild<QSpinBox *>(u"line"_s);
     QVERIFY(line->hasFocus());
     edit.setFocus();
     QVERIFY(!line->hasFocus());
@@ -127,7 +129,7 @@ void TextGoToLineWidgetTest::shouldChangeMaximumValue()
     TextCustomEditor::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    auto line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto line = edit.findChild<QSpinBox *>(u"line"_s);
 
     QCOMPARE(line->value(), 1);
     QCOMPARE(line->minimum(), 1);
