@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,7 +11,7 @@
 #include <QWidget>
 namespace TextEditTextToSpeech
 {
-class AbstractTextToSpeechInterface;
+class TextToSpeechInterface;
 class TextToSpeechWidgetPrivate;
 /**
  * @brief The TextToSpeechWidget class
@@ -31,12 +31,12 @@ public:
     };
     Q_ENUM(State)
 
-    Q_REQUIRED_RESULT State state() const;
+    [[nodiscard]] State state() const;
     void setState(TextEditTextToSpeech::TextToSpeechWidget::State state);
 
-    void setTextToSpeechInterface(AbstractTextToSpeechInterface *interface);
+    void setTextToSpeechInterface(TextToSpeechInterface *interface);
 
-    Q_REQUIRED_RESULT bool isReady() const;
+    [[nodiscard]] bool isReady() const;
 
     void showWidget();
 
@@ -50,11 +50,11 @@ Q_SIGNALS:
     void changeVisibility(bool state);
 
 private:
-    void slotVolumeChanged(int value);
-    void slotCloseTextToSpeechWidget();
-    void slotConfigure();
-    void applyVolume();
-    void hideWidget();
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotVolumeChanged(int value);
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotCloseTextToSpeechWidget();
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotConfigure();
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void applyVolume();
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void hideWidget();
     std::unique_ptr<TextToSpeechWidgetPrivate> const d;
 };
 }
