@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ public:
 
     void setFontSize(int newFontSize);
 
-    Q_REQUIRED_RESULT bool isRecentView() const;
+    [[nodiscard]] bool isRecentView() const;
     void setIsRecentView(bool newIsRecentView);
 
 Q_SIGNALS:
@@ -32,7 +32,8 @@ protected:
     void contextMenuEvent(QContextMenuEvent *event) override;
 
 private:
-    void applyFontSize();
+    TEXTEMOTICONSWIDGETS_NO_EXPORT void applyFontSize();
+    TEXTEMOTICONSWIDGETS_NO_EXPORT void selectEmoji(const QModelIndex &index);
     int mFontSize = 18;
     int mRowSize = 0;
     bool mIsRecentView = false;
