@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,6 +9,7 @@
 #include <QJsonObject>
 
 using namespace TextGrammarCheck;
+using namespace Qt::Literals::StringLiterals;
 
 LanguageInfo::LanguageInfo() = default;
 
@@ -52,9 +53,9 @@ bool LanguageInfo::isValid() const
 
 void LanguageInfo::parse(const QJsonObject &obj)
 {
-    mName = obj[QStringLiteral("name")].toString();
-    mCode = obj[QStringLiteral("code")].toString();
-    mLongCode = obj[QStringLiteral("longCode")].toString();
+    mName = obj["name"_L1].toString();
+    mCode = obj["code"_L1].toString();
+    mLongCode = obj["longCode"_L1].toString();
 }
 
 bool LanguageInfo::operator==(const LanguageInfo &other) const
